/*
 * talkatu
 * Copyright (C) 2017-2018 Gary Kramlich <grim@reaperworld.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#if !defined(TALKATU_GLOBAL_HEADER_INSIDE) && !defined(TALKATU_COMPILATION)
#error "only <talkatu.h> may be included directly"
#endif

#ifndef TALKATU_MESSAGE_H
#define TALKATU_MESSAGE_H

#include <gtk/gtk.h>

#define TALKATU_TYPE_MESSAGE            (talkatu_message_get_type())
#define TALKATU_MESSAGE(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), TALKATU_TYPE_MESSAGE, TalkatuMessage))
#define TALKATU_IS_MESSAGE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), TALKATU_TYPE_MESSAGE))
#define TALKATU_MESSAGE_GET_IFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE((obj), TALKATU_TYPE_MESSAGE, TalkatuMessageInterface))

typedef struct _TalkatuMessage          TalkatuMessage;
typedef struct _TalkatuMessageInterface TalkatuMessageInterface;

typedef enum _TalkatuContentType /*< prefix=TALKATU_CONTENT_TYPE,underscore_name=TALKATU_CONTENT_TYPE >*/
{
	TALKATU_CONTENT_TYPE_PLAIN =  0,
	TALKATU_CONTENT_TYPE_PANGO,
	TALKATU_CONTENT_TYPE_HTML,
	TALKATU_CONTENT_TYPE_MARKDOWN,
} TalkatuContentType;

#include <glib.h>
#include <glib-object.h>

#include <gtk/gtk.h>

struct _TalkatuMessageInterface {
	/*< private >*/
	GTypeInterface parent;

	/*< private >*/
	void (*_talkatu_reserved1)(void);
	void (*_talkatu_reserved2)(void);
	void (*_talkatu_reserved3)(void);
	void (*_talkatu_reserved4)(void);
};

G_BEGIN_DECLS

GType talkatu_message_get_type(void);

guint64 talkatu_message_get_id(TalkatuMessage *message);
void talkatu_message_set_id(TalkatuMessage *message, guint64 id);

TalkatuContentType talkatu_message_get_content_type(TalkatuMessage *message);

gchar *talkatu_message_get_author(TalkatuMessage *message);
void talkatu_message_set_author(TalkatuMessage *message, const gchar *author);

gchar *talkatu_message_get_contents(TalkatuMessage *message);
void talkatu_message_set_contents(TalkatuMessage *message, const gchar *contents);

G_END_DECLS

#endif /* TALKATU_MESSAGE_H */
